==> nextcloud-12.0.2.tgz: nextcloud/apps/gallery/l10n/ar.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "معرض صور",
    "New" : "جديد",
    "Error loading slideshow template" : "خطأ في تحميل قالب عرض الشرائح.",
    "Next" : "التالي",
    "Play" : "تشغيل",
    "Pause" : "إيقاف",
    "Previous" : "السابق",
    "Close" : "إغلاق",
    "Download" : "تنزيل",
    "Delete" : "حذف ",
    "Could not create file \"{file}\" because it already exists" : "لا يمكن إنشاء الملف \"{file}\" فهو موجود بالفعل",
    "Could not create file \"{file}\"" : "لا يمكن إنشاء الملف\"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" اسم ملف غير صالح للاستخدام .",
    "File name cannot be empty." : "اسم الملف لا يجوز أن يكون فارغا",
    "Upload" : "رفع",
    "Error" : "خطأ",
    "Error while sharing" : "حصل خطأ عند عملية المشاركة",
    "Error while unsharing" : "حصل خطأ عند عملية إزالة المشاركة",
    "Error while changing permissions" : "حصل خطأ عند عملية إعادة تعيين التصريح بالتوصل",
    "Shared with you and the group {group} by {owner}" : "شورك معك ومع المجموعة {group} من قبل {owner}",
    "Shared with you by {owner}" : "شورك معك من قبل {owner}",
    "Share with users or groups …" : "شارِك مع مستخدمين أو مجموعات",
    "Share with users, groups or remote users …" : "شارِك مع مستخدمين أو مجموعات أو مستخدمين عن بُعد",
    "Share" : "شارك",
    "Share link" : "شارك الرابط",
    "Link" : "الرابط",
    "Password protect" : "حماية كلمة السر",
    "Password" : "كلمة السر",
    "Choose a password for the public link" : "اختر كلمة مرور للرابط العام",
    "Allow editing" : "السماح بالتعديلات",
    "Email link to person" : "ارسل الرابط بالبريد الى صديق",
    "Send" : "أرسل",
    "Set expiration date" : "تعيين تاريخ إنتهاء الصلاحية",
    "Expiration" : "إنتهاء",
    "Expiration date" : "تاريخ إنتهاء الصلاحية",
    "Adding user..." : "إضافة مستخدم",
    "group" : "مجموعة",
    "remote" : "عن بعد",
    "Resharing is not allowed" : "لا يسمح بعملية إعادة المشاركة",
    "Unshare" : "إلغاء المشاركة",
    "notify by email" : "الإشعار عن طريق البريد",
    "can share" : "يمكن المشاركة",
    "can edit" : "يمكن التحرير",
    "access control" : "ضبط الوصول",
    "create" : "إنشاء",
    "change" : "تغيير",
    "delete" : "حذف",
    "Password protected" : "محمي بكلمة السر",
    "Error unsetting expiration date" : "حصل خطأ عند عملية إزالة تاريخ إنتهاء الصلاحية",
    "Error setting expiration date" : "حصل خطأ عند عملية تعيين تاريخ إنتهاء الصلاحية",
    "Sending ..." : "جاري الارسال ...",
    "Email sent" : "تم ارسال البريد الالكتروني",
    "Warning" : "تحذير",
    "This share is password-protected" : "هذه المشاركة محمية بكلمة مرور",
    "The password is wrong. Try again." : "كلمة المرور خاطئة. حاول مرة أخرى",
    "Cancel upload" : "إلغاء الرفع",
    "File list" : "قائمة الملفات",
    "Reasons might be:" : "الأسباب الممكنة :",
    "the item was removed" : "تم حذف العنصر المطلوب",
    "sharing is disabled" : "المشاركة غير مفعلة",
    "Picture view" : "عرض الصورة"
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-15.0.5p1.tgz: nextcloud/apps/gallery/l10n/ar.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "معرض صور",
    "Error loading slideshow template" : "خطأ في تحميل قالب عرض الشرائح.",
    "Next" : "التالي",
    "Play" : "تشغيل",
    "Pause" : "إيقاف",
    "Previous" : "السابق",
    "Close" : "إغلاق",
    "Download" : "تنزيل",
    "Delete" : "حذف ",
    "Share" : "شارك",
    "Could not create file \"{file}\" because it already exists" : "لا يمكن إنشاء الملف \"{file}\" فهو موجود بالفعل",
    "Could not create file \"{file}\"" : "لا يمكن إنشاء الملف\"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" اسم ملف غير صالح للاستخدام .",
    "File name cannot be empty." : "اسم الملف لا يجوز أن يكون فارغا",
    "Upload" : "رفع",
    "Error" : "خطأ",
    "Error while sharing" : "حصل خطأ عند عملية المشاركة",
    "Error while unsharing" : "حصل خطأ عند عملية إزالة المشاركة",
    "Error while changing permissions" : "حصل خطأ عند عملية إعادة تعيين التصريح بالتوصل",
    "Shared with you and the group {group} by {owner}" : "شورك معك ومع المجموعة {group} من قبل {owner}",
    "Shared with you by {owner}" : "شورك معك من قبل {owner}",
    "Share with users or groups …" : "شارِك مع مستخدمين أو مجموعات",
    "Share with users, groups or remote users …" : "شارِك مع مستخدمين أو مجموعات أو مستخدمين عن بُعد",
    "Share link" : "شارك الرابط",
    "Link" : "الرابط",
    "Password protect" : "حماية كلمة السر",
    "Password" : "كلمة السر",
    "Choose a password for the public link" : "اختر كلمة مرور للرابط العام",
    "Allow editing" : "السماح بالتعديلات",
    "Email link to person" : "ارسل الرابط بالبريد الى صديق",
    "Send" : "أرسل",
    "Set expiration date" : "تعيين تاريخ إنتهاء الصلاحية",
    "Expiration" : "إنتهاء",
    "Expiration date" : "تاريخ إنتهاء الصلاحية",
    "Adding user..." : "إضافة مستخدم",
    "group" : "مجموعة",
    "remote" : "عن بعد",
    "Resharing is not allowed" : "لا يسمح بعملية إعادة المشاركة",
    "Unshare" : "إلغاء المشاركة",
    "notify by email" : "الإشعار عن طريق البريد",
    "can share" : "يمكن المشاركة",
    "can edit" : "يمكن التحرير",
    "access control" : "ضبط الوصول",
    "create" : "إنشاء",
    "change" : "تغيير",
    "delete" : "حذف",
    "Password protected" : "محمي بكلمة السر",
    "Error unsetting expiration date" : "حصل خطأ عند عملية إزالة تاريخ إنتهاء الصلاحية",
    "Error setting expiration date" : "حصل خطأ عند عملية تعيين تاريخ إنتهاء الصلاحية",
    "Email sent" : "تم ارسال البريد الالكتروني",
    "Warning" : "تحذير",
    "This share is password-protected" : "هذه المشاركة محمية بكلمة مرور",
    "The password is wrong. Try again." : "كلمة المرور خاطئة. حاول مرة أخرى",
    "Cancel upload" : "إلغاء الرفع",
    "File list" : "قائمة الملفات",
    "Reasons might be:" : "الأسباب الممكنة :",
    "the item was removed" : "تم حذف العنصر المطلوب",
    "sharing is disabled" : "المشاركة غير مفعلة",
    "Picture view" : "عرض الصورة",
    "New" : "جديد",
    "Sending ..." : "جاري الارسال ..."
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
